<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" version="1.0">
	<!--
	This file belongs to XMLReleaseNotes V@XRN_VERSION@.
	-->
	<!--
	The aim of this model XSLT is to integrate the CVS XML change log information into a release notes.
	In order to use it, you will need Ant in order to produce this CVS XML change log file, or you need to produce it by yourself...
	-->
	<xsl:import href="XMLReleaseNotesCommon.xsl"/>
	<xsl:import href="XRNModelCommon.xsl"/>
	<xsl:output method="xml" indent="yes"/>
	<!--
	This indicates the path of the CVS XML change log file that applies to this version, and produced by the Ant 'cvschangelog' task.
	-->
	<xsl:param name="CVSChangeLogFile" select="'cvschangelog.xml'"/>
	<!--
	This is the release version the CVS change logs should be added to.
	-->
	<xsl:param name="releaseVersion"/>
	<!--
	This flag indicates whether each CVS commit action should produce a single 'Feature' or not.
	-->
	<xsl:param name="split" select="true()"/>
	<xsl:template match="xrn:ReleaseNotes/xrn:Releases/xrn:Release">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:copy-of select="@*[not(name() = 'Features')]"/>
			<xsl:choose>
				<xsl:when test="@version = $releaseVersion">
					<xsl:choose>
						<xsl:when test="xrn:Features">
							<xsl:for-each select="xrn:Features">
								<xsl:copy>
									<xsl:copy-of select="@*"/>
									<xsl:copy-of select="*"/>
									<xsl:call-template name="printCVSFeature"/>
								</xsl:copy>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<Features xmlns="http://xmlreleasenotes.free.fr">
								<xsl:call-template name="printCVSFeature"/>
							</Features>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="xrn:Features"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>
	<xsl:template name="printCVSFeature">
		<xsl:choose>
			<xsl:when test="$split = true()">
				<xsl:for-each select="document($CVSChangeLogFile)/changelog/entry">
					<xsl:sort select="date/text()" order="descending"/>
					<xsl:sort select="time/text()" order="descending"/>
					<Feature type="vsc" xmlns="http://xmlreleasenotes.free.fr">
						<xsl:attribute name="ID"><xsl:value-of select="file/name"/></xsl:attribute>
						<Contributors>
							<Actor>
								<xsl:attribute name="ID"><xsl:value-of select="author"/></xsl:attribute>
							</Actor>
						</Contributors>
						<Item contentType="html">
							<xsl:text><![CDATA[<font size="-2"><u>]]></xsl:text>
							<xsl:value-of select="date"/>
							<xsl:text> </xsl:text>
							<xsl:value-of select="time"/>
							<xsl:text><![CDATA[</u>]]></xsl:text>
							<xsl:text> </xsl:text>
							<xsl:value-of select="msg"/>
							<xsl:text><![CDATA[</font>]]></xsl:text>
						</Item>
					</Feature>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<Feature ID="CVS" type="vsc" xmlns="http://xmlreleasenotes.free.fr">
					<Title>These are the CVS change logs since the previous version.</Title>
					<xsl:for-each select="document($CVSChangeLogFile)/changelog/entry">
						<xsl:sort select="date/text()" order="descending"/>
						<xsl:sort select="time/text()" order="descending"/>
						<Item contentType="html">
							<xsl:text><![CDATA[<font size="-2"><u>]]></xsl:text>
							<xsl:value-of select="date"/>
							<xsl:text> </xsl:text>
							<xsl:value-of select="time"/>
							<xsl:text><![CDATA[</u>]]></xsl:text>
							<xsl:text> </xsl:text>
							<xsl:text><![CDATA[<code>]]></xsl:text>
							<xsl:value-of select="file/name"/>
							<xsl:text><![CDATA[</code>]]></xsl:text>
							<xsl:text> </xsl:text>
							<xsl:value-of select="msg"/>
							<xsl:text><![CDATA[<div class="contributorID" align="right">]]></xsl:text>
							<xsl:value-of select="author"/>
							<xsl:text><![CDATA[</div></font>]]></xsl:text>
						</Item>
					</xsl:for-each>
				</Feature>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
