<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr">
	<!--
	This file belongs to XMLReleaseNotes V@XRN_VERSION@.
	-->
	<!--
	Detailed explanations are available in the stylesheet 'XRN2HTMLPlugin.xsl'.
	-->
	<!--
	Overrides the default one.
	-->
	<xsl:template name="showPlugins">
		<plugins>
			<level name="component">
				<plugin name="reference" suffixURL="reference.html"/>
			</level>
			<level name="release">
				<plugin name="reference" suffixURL="reference.html"/>
			</level>
		</plugins>
	</xsl:template>
	<!--
	Overrides the default one.
	Generates the page for the one plugin.
	-->
	<xsl:template name="runPlugin">
		<xsl:param name="level"/>
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$level = 'component'">
				<xsl:choose>
					<xsl:when test="$index = 1">
						<xsl:call-template name="_printComponentReference"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$level = 'release'">
				<xsl:choose>
					<xsl:when test="$index = 1">
						<xsl:call-template name="_printComponentReleaseReference"/>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--
	This templates outputs all component references on the current component.
	The current node should be a 'xrn:ReleaseNotes' XML element.
	-->
	<xsl:template name="_printComponentReference">
		<h2>
			<xsl:text>Component </xsl:text>
			<xsl:value-of select="@ID"/>
			<xsl:text> references</xsl:text>
		</h2>
		<xsl:text>This page shows the locations where the current component is being used at.</xsl:text>
		<xsl:call-template name="_printComponentReferencesBlock">
			<xsl:with-param name="block" select="'Composition'"/>
		</xsl:call-template>
		<xsl:call-template name="_printComponentReferencesBlock">
			<xsl:with-param name="block" select="'Dependencies'"/>
		</xsl:call-template>
		<xsl:call-template name="_printComponentReferencesBlock">
			<xsl:with-param name="block" select="'Requirements'"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="_printComponentReferencesBlock">
		<xsl:param name="block"/>
		<xsl:variable name="componentID" select="@ID"/>
		<p>
			<table class="{$block}" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">
										<xsl:value-of select="$block"/>
									</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:for-each select="../xrn:ReleaseNotes">
						<xsl:variable name="referencesHTMLStuf">
							<xsl:for-each select="xrn:Releases/xrn:Release">
								<xsl:variable name="isPartOf">
									<xsl:call-template name="_isPartOfRelease">
										<xsl:with-param name="block" select="$block"/>
										<xsl:with-param name="componentID" select="$componentID"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:if test="not($isPartOf = '')">
									<xsl:call-template name="_writeComponentReleaseA">
										<xsl:with-param name="ID" select="../../@ID"/>
										<xsl:with-param name="version" select="@version"/>
										<xsl:with-param name="withID" select="false()"/>
									</xsl:call-template>
									<xsl:text> </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:variable>
						<xsl:if test="not($referencesHTMLStuf = '')">
							<tr>
								<xsl:attribute name="class"><xsl:value-of select="$block"/>Component</xsl:attribute>
								<td width="20%">
									<xsl:call-template name="_writeComponentA">
										<xsl:with-param name="ID" select="@ID"/>
									</xsl:call-template>
								</td>
								<td width="80%">
									<xsl:copy-of select="$referencesHTMLStuf"/>
								</td>
							</tr>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</p>
		<p>
			<xsl:text>&#160;</xsl:text>
		</p>
	</xsl:template>
	<!--
	This templates outputs all component references on a precise release of the current component.
	The current node should be a 'Releases/Release' XML element.
	-->
	<xsl:template name="_printComponentReleaseReference">
		<h2>
			<xsl:text>Component </xsl:text>
			<xsl:value-of select="../../@ID"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="@version"/>
			<xsl:text> references</xsl:text>
		</h2>
		<xsl:text>This page shows the locations where the current component version release is being used at.</xsl:text>
		<xsl:call-template name="_printComponentReleaseReferencesBlock">
			<xsl:with-param name="block" select="'Composition'"/>
		</xsl:call-template>
		<xsl:call-template name="_printComponentReleaseReferencesBlock">
			<xsl:with-param name="block" select="'Dependencies'"/>
		</xsl:call-template>
		<xsl:call-template name="_printComponentReleaseReferencesBlock">
			<xsl:with-param name="block" select="'Requirements'"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="_printComponentReleaseReferencesBlock">
		<xsl:param name="block"/>
		<xsl:variable name="componentID" select="../../@ID"/>
		<xsl:variable name="componentVersion" select="@version"/>
		<p>
			<table class="{$block}" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">
										<xsl:value-of select="$block"/>
									</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:for-each select="../../../xrn:ReleaseNotes">
						<xsl:variable name="referencesHTMLStuf">
							<xsl:for-each select="xrn:Releases/xrn:Release">
								<xsl:variable name="isPartOf">
									<xsl:call-template name="_isPartOfRelease">
										<xsl:with-param name="block" select="$block"/>
										<xsl:with-param name="componentID" select="$componentID"/>
										<xsl:with-param name="componentVersion" select="$componentVersion"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:if test="not($isPartOf = '')">
									<xsl:call-template name="_writeComponentReleaseA">
										<xsl:with-param name="ID" select="../../@ID"/>
										<xsl:with-param name="version" select="@version"/>
										<xsl:with-param name="withID" select="false()"/>
									</xsl:call-template>
									<xsl:text> </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:variable>
						<xsl:if test="not($referencesHTMLStuf = '')">
							<tr>
								<xsl:attribute name="class"><xsl:value-of select="$block"/>Component</xsl:attribute>
								<td width="20%">
									<xsl:call-template name="_writeComponentA">
										<xsl:with-param name="ID" select="@ID"/>
									</xsl:call-template>
								</td>
								<td width="80%">
									<xsl:copy-of select="$referencesHTMLStuf"/>
								</td>
							</tr>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</p>
		<p>
			<xsl:text>&#160;</xsl:text>
		</p>
	</xsl:template>
	<!--
	When the 'componentVersion' parameter is empty, null or not provided, the template discards this version information.
	-->
	<xsl:template name="_isPartOfRelease">
		<xsl:param name="block"/>
		<xsl:param name="componentID"/>
		<xsl:param name="componentVersion"/>
		<xsl:choose>
			<xsl:when test="*[name() = $block]/xrn:Component[@ID = $componentID and ($componentVersion = '' or @version= $componentVersion)]">
				<!-- The reference is expressed at the same release level -->
				<xsl:text>1</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="release_newest">
					<xsl:call-template name="_printComponentNewestInheritancePosition">
						<xsl:with-param name="block" select="$block"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="release_oldest">
					<xsl:call-template name="_printComponentOldestInheritancePosition">
						<xsl:with-param name="block" select="$block"/>
						<xsl:with-param name="release_newest" select="$release_newest"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:for-each select="../xrn:Release">
					<xsl:variable name="release" select="position()"/>
					<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
						<xsl:if test="*[name() = $block]/xrn:Component[@ID = $componentID and ($componentVersion = '' or @version= $componentVersion)]">
							<xsl:text>1</xsl:text>
						</xsl:if>
					</xsl:if>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="_printComponentNewestInheritancePosition">
		<xsl:param name="block"/>
		<xsl:choose>
			<xsl:when test="xrn:Composition">
				<xsl:value-of select="count(preceding-sibling::xrn:Release) + 1"/>
			</xsl:when>
			<xsl:when test="count(following-sibling::xrn:Release[count(*[name() = $block]) > 0]) != 0">
				<xsl:value-of select="count((following-sibling::xrn:Release[count(*[name() = $block]) > 0])[1]/preceding-sibling::xrn:Release) + 1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="count(../xrn:Release)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="_printComponentOldestInheritancePosition">
		<xsl:param name="block"/>
		<xsl:param name="release_newest"/>
		<xsl:choose>
			<xsl:when test="count(../xrn:Release[position() >= $release_newest and *[name() = $block]/@inherit = 'false']) != 0">
				<xsl:value-of select="count((../xrn:Release[position() >= $release_newest and *[name() = $block]/@inherit = 'false'])[1]/preceding-sibling::xrn:Release) + 1"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="count(../xrn:Release)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
